Author: void
Date: Mon Dec 17 17:19:54 2007
New Revision: 45133

URL: http://llvm.org/viewvc/llvm-project?rev=45133&view=rev
Log:
s/hasSideEffects/hasUnmodelledSideEffects/g

Modified:
    llvm/trunk/include/llvm/Target/TargetInstrInfo.h

Modified: llvm/trunk/include/llvm/Target/TargetInstrInfo.h
URL: 
http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Target/TargetInstrInfo.h?rev=45133&r1=45132&r2=45133&view=diff

==============================================================================
--- llvm/trunk/include/llvm/Target/TargetInstrInfo.h (original)
+++ llvm/trunk/include/llvm/Target/TargetInstrInfo.h Mon Dec 17 17:19:54 2007
@@ -314,9 +314,10 @@
            isReallyTriviallyReMaterializable(MI);
   }
 
-  /// hasSideEffects - Returns true if the instruction has side effects that 
are
-  /// not captured by any operands of the instruction or other flags.
-  bool hasSideEffects(MachineInstr *MI) const {
+  /// hasUnmodelledSideEffects - Returns true if the instruction has side
+  /// effects that are not captured by any operands of the instruction or other
+  /// flags.
+  bool hasUnmodelledSideEffects(MachineInstr *MI) const {
     const TargetInstrDescriptor *TID = MI->getInstrDescriptor();
     if (!(TID->Flags & M_NEVER_HAS_SIDE_EFFECTS ||
           TID->Flags & M_MAY_HAVE_SIDE_EFFECTS)) return true;


_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to